#include <Qdebug>
#include "client.h"
#include "oscpkt/oscpkt.hh"

using namespace oscpkt;

Client::Client(QString address, int port, QString OSCAddress, int OSCport, QStringList labels) :
    _OSCAddress(OSCAddress),
    _OSCport(OSCport),
    _featureLabels(labels)
{
    QObject::connect(&_tcpSock, SIGNAL(readyRead()), this, SLOT(readFeatureData()));
    QObject::connect(&_tcpSock, SIGNAL(error(QAbstractSocket::SocketError)), this, SLOT(onError()));

    _udpSock.connectToHost(_OSCAddress, _OSCport);
    _tcpSock.connectToHost(address, port);

}

void Client::readFeatureData()
{
    QString strReceived(_tcpSock.readAll());

    if(strReceived.isEmpty() || strReceived.isNull())
        return;

    //qDebug() << strReceived;
    QStringList strFeatures = strReceived.split( "\t", QString::SkipEmptyParts);

    int nFeatures = qMin(strFeatures.length(), _featureLabels.length());

    PacketWriter pw;
    pw.startBundle().startBundle();
    for(int i = 0; i < nFeatures; i++)
    {
        Message msg(_featureLabels[i].toAscii().data());
        msg.pushDouble(strFeatures[i].toDouble());
        pw.addMessage(msg);
    }
    pw.endBundle().endBundle();
    _udpSock.write(pw.packetData(), pw.packetSize());


}

void Client::onError()
{
    qDebug() << _tcpSock.errorString();
}
