#include <QCoreApplication>
#include <QStringList>

#include "client.h"

#define PORT_FEATURE        7125
#define PORT_RAW_DATA       7126
#define PORT_BP             1234

#define DEAFULT_IP_ADDRESS  "localhost"
#define DEFAULT_OSC_ADDRESS "239.200.200.200"
#define DEFAULT_OSC_PORT    9977

int main(int argc, char *argv[])
{
    QCoreApplication a(argc, argv);

    QStringList labels;
    QString ipAddress = DEAFULT_IP_ADDRESS;
    int port = 0;
    QString OSCAddress = DEFAULT_OSC_ADDRESS;
    int OSCport = DEFAULT_OSC_PORT;

    if (argc > 1 && strcmp(argv[1], "--raw") == 0) {
        port = PORT_RAW_DATA;
        for(int i = 1; i <= 20; i++)
        {
            labels.append("/channel" + QString::number(i));
        }
    } else if (argc > 1 && strcmp(argv[1], "--feature") == 0) {
        port = PORT_FEATURE;
        for(int i = 1; i < 5; i++)
        {
            labels.append("/feature" + QString::number(i));
        }
    } else if (argc > 1 && strcmp(argv[1], "--bp") == 0) {
        port = PORT_BP;
        labels.append("/Valence");
        labels.append("/Arousal");
        labels.append("/HR");
        labels.append("/HRV");
        labels.append("/HeartBeat");
        labels.append("/EMG");
        labels.append("/Accel");
        labels.append("/Mov");
    }
    else {
        qDebug() << "syntax: --raw to parse raw data from Feature Server,";
        qDebug() << "        --feature to parse features from Feature Server,";
        qDebug() << "        --bp to parse features from BreainPolyphony application";
        qDebug() << "        [IP address] where the Feature Server/BrainPolyphony runs (default value: \"localhost\")";
        qDebug() << "        [OSC IP address] where the OSC messages are sent (default value: \"239.200.200.200\")";
        qDebug() << "        [OSC port] where the OSC messages are sent (default value: 9977)";
        exit(-1);
    }
    if (argc > 2)
    {
        ipAddress = QString(argv[2]);
    }
    if (argc > 3)
    {
        OSCAddress = QString(argv[3]);
    }
    if (argc > 4)
    {
        OSCport = QString(argv[4]).toInt();
    }
    Client client(ipAddress, port, OSCAddress, OSCport, labels);

    return a.exec();
}
